@@ -13,7 +13,7 @@ use warnings;
 
 package Games::Risk::Tk::Continents;
 {
-  $Games::Risk::Tk::Continents::VERSION = '3.112450';
+  $Games::Risk::Tk::Continents::VERSION = '3.112590';
 }
 # ABSTRACT: continents information
 
@@ -32,8 +32,9 @@ use Tk::TableMatrix;
 with 'Tk::Role::Dialog' => { -version => 1.112380 }; # _clear_w
 
 
-use Games::Risk::I18n  qw{ T };
-use Games::Risk::Utils qw{ $SHAREDIR debug };
+use Games::Risk::I18n   qw{ T };
+use Games::Risk::Logger qw{ debug };
+use Games::Risk::Utils  qw{ $SHAREDIR };
 
 Readonly my $K => $poe_kernel;
 
@@ -168,7 +169,7 @@ sub _build_gui {
     my ($self, $f) = @_;
 
     # populate continents list
-    my $map = Games::Risk->new->map;
+    my $map = Games::Risk->instance->map;
     my @continents =
         sort {
              $b->bonus <=> $a->bonus ||
@@ -199,10 +200,11 @@ sub _build_gui {
     $tm->tagCell( 'title', "0,$_" ) for 0..2;
     my $row = 0;
     foreach my $c ( @continents ) {
+        my @countries = $c->countries;
         $row++;
         $self->_set_value( "$row,0", $c->name );
         $self->_set_value( "$row,1", $c->bonus );
-        $self->_set_value( "$row,2", scalar( $c->countries ) );
+        $self->_set_value( "$row,2", scalar( @countries ) );
         $tm->tagCell( 'left', "$row,0" );
         $tm->tagCell( 'static', "$row,$_" ) for 1..2;
     }
@@ -226,7 +228,7 @@ Games::Risk::Tk::Continents - continents information
 
 =head1 VERSION
 
-version 3.112450
+version 3.112590
 
 =head1 DESCRIPTION
 
